This is an automated email from the ASF dual-hosted git repository.

rusackas pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/superset.git


The following commit(s) were added to refs/heads/master by this push:
     new ee06d3d113 Fix typo issue in Error handling message (#20365)
ee06d3d113 is described below

commit ee06d3d113cd7d61e6e5e6162c59a66d775e7779
Author: Smart-Codi <[email protected]>
AuthorDate: Mon Jun 13 21:29:18 2022 +0100

    Fix typo issue in Error handling message (#20365)
---
 superset/reports/commands/alert.py                    | 8 ++++----
 superset/reports/commands/exceptions.py               | 4 ++--
 superset/translations/de/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/de/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/en/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/en/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/es/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/es/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/fr/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/fr/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/it/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/it/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/ja/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/ja/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/ko/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/ko/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/messages.pot                    | 8 ++++----
 superset/translations/nl/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/nl/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/pt/LC_MESSAGES/message.json     | 8 ++++----
 superset/translations/pt/LC_MESSAGES/message.po       | 8 ++++----
 superset/translations/pt_BR/LC_MESSAGES/messages.json | 8 ++++----
 superset/translations/pt_BR/LC_MESSAGES/messages.po   | 8 ++++----
 superset/translations/ru/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/ru/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/sk/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/sk/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/sl/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/sl/LC_MESSAGES/messages.po      | 8 ++++----
 superset/translations/zh/LC_MESSAGES/messages.json    | 8 ++++----
 superset/translations/zh/LC_MESSAGES/messages.po      | 8 ++++----
 31 files changed, 122 insertions(+), 122 deletions(-)

diff --git a/superset/reports/commands/exceptions.py 
b/superset/reports/commands/exceptions.py
index b78f99afe9..db46503b93 100644
--- a/superset/reports/commands/exceptions.py
+++ b/superset/reports/commands/exceptions.py
@@ -178,7 +178,7 @@ class 
ReportScheduleCreationMethodUniquenessValidationError(CommandException):
 
 class AlertQueryMultipleRowsError(CommandException):
 
-    message = _("Alert query returned more then one row.")
+    message = _("Alert query returned more than one row.")
 
 
 class AlertValidatorConfigError(CommandException):
@@ -187,7 +187,7 @@ class AlertValidatorConfigError(CommandException):
 
 
 class AlertQueryMultipleColumnsError(CommandException):
-    message = _("Alert query returned more then one column.")
+    message = _("Alert query returned more than one column.")
 
 
 class AlertQueryInvalidTypeError(CommandException):
diff --git a/superset/translations/de/LC_MESSAGES/messages.json 
b/superset/translations/de/LC_MESSAGES/messages.json
index 98cd4e6947..9abf6b6d8a 100644
--- a/superset/translations/de/LC_MESSAGES/messages.json
+++ b/superset/translations/de/LC_MESSAGES/messages.json
@@ -279,16 +279,16 @@
       "Alert query returned a non-number value.": [
         "Die Alarm-Abfrage hat einen nicht-numerischen Wert zurückgegeben."
       ],
-      "Alert query returned more then one column.": [
+      "Alert query returned more than one column.": [
         "Die Alarm-Abfrage hat mehr als eine Spalte zurückgegeben."
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "Die Alarmabfrage hat mehr als eine Spalte zurückgegeben. %s Spalten 
zurückgegegeben"
       ],
-      "Alert query returned more then one row.": [
+      "Alert query returned more than one row.": [
         "Die Alarm-Abfrage hat mehr als eine Zeile zurückgegeben."
       ],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "Die Alarmabfrage hat mehr als eine Zeile zurückgegeben. %s 
zurückgegebene Zeilen"
       ],
       "Alert running": ["Alarm wird ausgeführt"],
diff --git a/superset/translations/de/LC_MESSAGES/messages.po 
b/superset/translations/de/LC_MESSAGES/messages.po
index 6feca31c40..8726ceae19 100644
--- a/superset/translations/de/LC_MESSAGES/messages.po
+++ b/superset/translations/de/LC_MESSAGES/messages.po
@@ -1028,23 +1028,23 @@ msgid "Alert query returned a non-number value."
 msgstr "Die Alarm-Abfrage hat einen nicht-numerischen Wert zurückgegeben."
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "Die Alarm-Abfrage hat mehr als eine Spalte zurückgegeben."
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr ""
 "Die Alarmabfrage hat mehr als eine Spalte zurückgegeben. %s Spalten "
 "zurückgegegeben"
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "Die Alarm-Abfrage hat mehr als eine Zeile zurückgegeben."
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 "Die Alarmabfrage hat mehr als eine Zeile zurückgegeben. %s zurückgegebene"
 " Zeilen"
diff --git a/superset/translations/en/LC_MESSAGES/messages.json 
b/superset/translations/en/LC_MESSAGES/messages.json
index 912c9fde70..f344b2c2ec 100644
--- a/superset/translations/en/LC_MESSAGES/messages.json
+++ b/superset/translations/en/LC_MESSAGES/messages.json
@@ -455,8 +455,8 @@
         "",
         "Deleted %(num)d report schedules"
       ],
-      "Alert query returned more then one row. %s rows returned": [""],
-      "Alert query returned more then one column. %s columns returned": [""],
+      "Alert query returned more than one row. %s rows returned": [""],
+      "Alert query returned more than one column. %s columns returned": [""],
       "Dashboard does not exist": [""],
       "Chart does not exist": [""],
       "Database is required for alerts": [""],
@@ -473,9 +473,9 @@
       "Report Schedule execution got an unexpected error.": [""],
       "Report Schedule is still working, refusing to re-compute.": [""],
       "Report Schedule reached a working timeout.": [""],
-      "Alert query returned more then one row.": [""],
+      "Alert query returned more than one row.": [""],
       "Alert validator config error.": [""],
-      "Alert query returned more then one column.": [""],
+      "Alert query returned more than one column.": [""],
       "Alert query returned a non-number value.": [""],
       "Alert found an error while executing a query.": [""],
       "Alert fired during grace period.": [""],
diff --git a/superset/translations/en/LC_MESSAGES/messages.po 
b/superset/translations/en/LC_MESSAGES/messages.po
index 332f0e50c4..4fb9477b0f 100644
--- a/superset/translations/en/LC_MESSAGES/messages.po
+++ b/superset/translations/en/LC_MESSAGES/messages.po
@@ -919,21 +919,21 @@ msgid "Alert query returned a non-number value."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr ""
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr ""
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/es/LC_MESSAGES/messages.json 
b/superset/translations/es/LC_MESSAGES/messages.json
index a7f2a4738b..71487fc750 100644
--- a/superset/translations/es/LC_MESSAGES/messages.json
+++ b/superset/translations/es/LC_MESSAGES/messages.json
@@ -688,10 +688,10 @@
         "",
         "Deleted %(num)d report schedules"
       ],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "La consulta de alerta devolvió más de una fila. %s filas devueltas"
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "La consulta de alerta devolvió más de una columna. %s columnas 
devueltas"
       ],
       "Dashboard does not exist": ["El dashboard no existe"],
@@ -734,13 +734,13 @@
       "Report Schedule reached a working timeout.": [
         "El informe programado alcanzó el tiempo de espera máximo."
       ],
-      "Alert query returned more then one row.": [
+      "Alert query returned more than one row.": [
         "La consulta de alerta devolvió más de una fila."
       ],
       "Alert validator config error.": [
         "Error de configuración del validador de alertas."
       ],
-      "Alert query returned more then one column.": [
+      "Alert query returned more than one column.": [
         "La consulta de alerta devolvió más de una columna."
       ],
       "Alert query returned a non-number value.": [
diff --git a/superset/translations/es/LC_MESSAGES/messages.po 
b/superset/translations/es/LC_MESSAGES/messages.po
index 2270f0db52..54845502ec 100644
--- a/superset/translations/es/LC_MESSAGES/messages.po
+++ b/superset/translations/es/LC_MESSAGES/messages.po
@@ -967,21 +967,21 @@ msgid "Alert query returned a non-number value."
 msgstr "La consulta de alerta devolvió un valor no numérico."
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "La consulta de alerta devolvió más de una columna."
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr "La consulta de alerta devolvió más de una columna. %s columnas 
devueltas"
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "La consulta de alerta devolvió más de una fila."
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr "La consulta de alerta devolvió más de una fila. %s filas devueltas"
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/fr/LC_MESSAGES/messages.json 
b/superset/translations/fr/LC_MESSAGES/messages.json
index ddcf3d746d..0f97274571 100644
--- a/superset/translations/fr/LC_MESSAGES/messages.json
+++ b/superset/translations/fr/LC_MESSAGES/messages.json
@@ -993,10 +993,10 @@
         "%(num)d planifications de rapport supprimées"
       ],
       "Value must be greater than 0": ["La valeur doit être plus grande que 
0"],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "La requête a retourné plus d'une ligne. %s lignes retournées"
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "La requête a retourné plus d'une colonne. %s colonnes retournées"
       ],
       "Dashboard does not exist": ["Le tableau de bord n'existe pas"],
@@ -1051,13 +1051,13 @@
       "Report Schedule reached a working timeout.": [
         "La planification de rapport a atteint un timeout d'exécution."
       ],
-      "Alert query returned more then one row.": [
+      "Alert query returned more than one row.": [
         "La requête a retourné plus d'une ligne."
       ],
       "Alert validator config error.": [
         "Erreur de configuration du validateur."
       ],
-      "Alert query returned more then one column.": [
+      "Alert query returned more than one column.": [
         "La requête a retourné plus d'une colonne."
       ],
       "Alert query returned a non-number value.": [
diff --git a/superset/translations/fr/LC_MESSAGES/messages.po 
b/superset/translations/fr/LC_MESSAGES/messages.po
index a54668777c..0661382664 100644
--- a/superset/translations/fr/LC_MESSAGES/messages.po
+++ b/superset/translations/fr/LC_MESSAGES/messages.po
@@ -1006,21 +1006,21 @@ msgid "Alert query returned a non-number value."
 msgstr "La requête a retourné une valeur non numérique."
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "La requête a retourné plus d'une colonne."
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr "La requête a retourné plus d'une colonne. %s colonnes retournées"
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "La requête a retourné plus d'une ligne."
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr "La requête a retourné plus d'une ligne. %s lignes retournées"
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/it/LC_MESSAGES/messages.json 
b/superset/translations/it/LC_MESSAGES/messages.json
index 3ae239dce5..733224efbe 100644
--- a/superset/translations/it/LC_MESSAGES/messages.json
+++ b/superset/translations/it/LC_MESSAGES/messages.json
@@ -501,8 +501,8 @@
       ],
       "Saved query not found.": [""],
       "Deleted %(num)d report schedule": [""],
-      "Alert query returned more then one row. %s rows returned": [""],
-      "Alert query returned more then one column. %s columns returned": [""],
+      "Alert query returned more than one row. %s rows returned": [""],
+      "Alert query returned more than one column. %s columns returned": [""],
       "Dashboard does not exist": [""],
       "Chart does not exist": [""],
       "Database is required for alerts": [""],
@@ -527,9 +527,9 @@
       "Report Schedule execution got an unexpected error.": [""],
       "Report Schedule is still working, refusing to re-compute.": [""],
       "Report Schedule reached a working timeout.": [""],
-      "Alert query returned more then one row.": [""],
+      "Alert query returned more than one row.": [""],
       "Alert validator config error.": [""],
-      "Alert query returned more then one column.": [""],
+      "Alert query returned more than one column.": [""],
       "Alert query returned a non-number value.": [""],
       "Alert found an error while executing a query.": [""],
       "Alert fired during grace period.": [""],
diff --git a/superset/translations/it/LC_MESSAGES/messages.po 
b/superset/translations/it/LC_MESSAGES/messages.po
index 41353893bc..3873a4b5a8 100644
--- a/superset/translations/it/LC_MESSAGES/messages.po
+++ b/superset/translations/it/LC_MESSAGES/messages.po
@@ -944,21 +944,21 @@ msgid "Alert query returned a non-number value."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr ""
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr ""
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/ja/LC_MESSAGES/messages.json 
b/superset/translations/ja/LC_MESSAGES/messages.json
index d0f2f9b93f..99e308cfa7 100644
--- a/superset/translations/ja/LC_MESSAGES/messages.json
+++ b/superset/translations/ja/LC_MESSAGES/messages.json
@@ -654,10 +654,10 @@
         " %(num)d 件のレポートスケジュールを削除しました"
       ],
       "Value must be greater than 0": ["値は 0 より大きくする必要があります"],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "アラートクエリが複数の行を返しました。 %s 行が返されました"
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "アラートクエリが複数の列を返しました。%s 列が返されました"
       ],
       "Dashboard does not exist": ["ダッシュボードが存在しません"],
@@ -701,11 +701,11 @@
       "Report Schedule reached a working timeout.": [
         "レポートスケジュールが作業タイムアウトに達しました。"
       ],
-      "Alert query returned more then one row.": [
+      "Alert query returned more than one row.": [
         "アラートクエリが複数の行を返しました。"
       ],
       "Alert validator config error.": ["アラートバリデーター設定エラー。"],
-      "Alert query returned more then one column.": [
+      "Alert query returned more than one column.": [
         "アラートクエリが複数の列を返しました。"
       ],
       "Alert query returned a non-number value.": [
diff --git a/superset/translations/ja/LC_MESSAGES/messages.po 
b/superset/translations/ja/LC_MESSAGES/messages.po
index f89d9f0b2b..d34ad5518c 100644
--- a/superset/translations/ja/LC_MESSAGES/messages.po
+++ b/superset/translations/ja/LC_MESSAGES/messages.po
@@ -938,21 +938,21 @@ msgid "Alert query returned a non-number value."
 msgstr "アラートクエリが数値以外の値を返しました。"
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "アラートクエリが複数の列を返しました。"
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr "アラートクエリが複数の列を返しました。%s 列が返されました"
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "アラートクエリが複数の行を返しました。"
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr "アラートクエリが複数の行を返しました。 %s 行が返されました"
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/ko/LC_MESSAGES/messages.json 
b/superset/translations/ko/LC_MESSAGES/messages.json
index 3949e99ed6..66cc9949a4 100644
--- a/superset/translations/ko/LC_MESSAGES/messages.json
+++ b/superset/translations/ko/LC_MESSAGES/messages.json
@@ -543,8 +543,8 @@
       "Saved query not found.": ["저장된 쿼리를 찾을 수 없습니다."],
       "Deleted %(num)d report schedule": [""],
       "Value must be greater than 0": ["값은 0보다 커야합니다"],
-      "Alert query returned more then one row. %s rows returned": [""],
-      "Alert query returned more then one column. %s columns returned": [""],
+      "Alert query returned more than one row. %s rows returned": [""],
+      "Alert query returned more than one column. %s columns returned": [""],
       "Dashboard does not exist": ["대시보드가 존재하지 않습니다"],
       "Chart does not exist": ["차트가 존재하지 않습니다"],
       "Database is required for alerts": [""],
@@ -561,9 +561,9 @@
       "Report Schedule execution got an unexpected error.": [""],
       "Report Schedule is still working, refusing to re-compute.": [""],
       "Report Schedule reached a working timeout.": [""],
-      "Alert query returned more then one row.": [""],
+      "Alert query returned more than one row.": [""],
       "Alert validator config error.": [""],
-      "Alert query returned more then one column.": [""],
+      "Alert query returned more than one column.": [""],
       "Alert query returned a non-number value.": [""],
       "Alert found an error while executing a query.": [""],
       "A timeout occurred while executing the query.": [""],
diff --git a/superset/translations/ko/LC_MESSAGES/messages.po 
b/superset/translations/ko/LC_MESSAGES/messages.po
index db408ecdcf..5b4530e039 100644
--- a/superset/translations/ko/LC_MESSAGES/messages.po
+++ b/superset/translations/ko/LC_MESSAGES/messages.po
@@ -938,21 +938,21 @@ msgid "Alert query returned a non-number value."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr ""
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr ""
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/messages.pot 
b/superset/translations/messages.pot
index 53f2e0506d..2233ec416a 100644
--- a/superset/translations/messages.pot
+++ b/superset/translations/messages.pot
@@ -925,21 +925,21 @@ msgid "Alert query returned a non-number value."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr ""
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr ""
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/nl/LC_MESSAGES/messages.json 
b/superset/translations/nl/LC_MESSAGES/messages.json
index 19ab66a085..699eb84297 100644
--- a/superset/translations/nl/LC_MESSAGES/messages.json
+++ b/superset/translations/nl/LC_MESSAGES/messages.json
@@ -909,10 +909,10 @@
         "Verwijderde %(num)d rapport schema’s"
       ],
       "Value must be greater than 0": ["Waarde moet groter zijn dan 0"],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "Alert query heeft meer dan één rij geretourneerd. %s rijen 
geretourneerd"
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "Alert query retourneerde meer dan één kolom. %s kolommen 
geretourneerd"
       ],
       "Dashboard does not exist": ["Het dashboard bestaat niet"],
@@ -965,13 +965,13 @@
       "Report Schedule reached a working timeout.": [
         "Rapportage planning heeft een werk time-out bereikt."
       ],
-      "Alert query returned more then one row.": [
+      "Alert query returned more than one row.": [
         "Alert query retourneerde meer dan één rij."
       ],
       "Alert validator config error.": [
         "Waarschuwing validator configuratiefout."
       ],
-      "Alert query returned more then one column.": [
+      "Alert query returned more than one column.": [
         "Alert query heeft meer dan één kolom geretourneerd."
       ],
       "Alert query returned a non-number value.": [
diff --git a/superset/translations/nl/LC_MESSAGES/messages.po 
b/superset/translations/nl/LC_MESSAGES/messages.po
index 0f454a727a..5db5e5ae4e 100644
--- a/superset/translations/nl/LC_MESSAGES/messages.po
+++ b/superset/translations/nl/LC_MESSAGES/messages.po
@@ -2415,13 +2415,13 @@ msgstr "Waarde moet groter zijn dan 0"
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 "Alert query heeft meer dan één rij geretourneerd. %s rijen geretourneerd"
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr "Alert query retourneerde meer dan één kolom. %s kolommen geretourneerd"
 
 #: superset/reports/commands/exceptions.py:44
@@ -2506,7 +2506,7 @@ msgid "Report Schedule reached a working timeout."
 msgstr "Rapportage planning heeft een werk time-out bereikt."
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "Alert query retourneerde meer dan één rij."
 
 #: superset/reports/commands/exceptions.py:182
@@ -2514,7 +2514,7 @@ msgid "Alert validator config error."
 msgstr "Waarschuwing validator configuratiefout."
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "Alert query heeft meer dan één kolom geretourneerd."
 
 #: superset/reports/commands/exceptions.py:190
diff --git a/superset/translations/pt/LC_MESSAGES/message.json 
b/superset/translations/pt/LC_MESSAGES/message.json
index 9ea04398fb..7ff52195f5 100644
--- a/superset/translations/pt/LC_MESSAGES/message.json
+++ b/superset/translations/pt/LC_MESSAGES/message.json
@@ -551,8 +551,8 @@
         "",
         "Deleted %(num)d report schedules"
       ],
-      "Alert query returned more then one row. %s rows returned": [""],
-      "Alert query returned more then one column. %s columns returned": [""],
+      "Alert query returned more than one row. %s rows returned": [""],
+      "Alert query returned more than one column. %s columns returned": [""],
       "Dashboard does not exist": [""],
       "Chart does not exist": [""],
       "Database is required for alerts": [""],
@@ -575,9 +575,9 @@
       "Report Schedule execution got an unexpected error.": [""],
       "Report Schedule is still working, refusing to re-compute.": [""],
       "Report Schedule reached a working timeout.": [""],
-      "Alert query returned more then one row.": [""],
+      "Alert query returned more than one row.": [""],
       "Alert validator config error.": [""],
-      "Alert query returned more then one column.": [""],
+      "Alert query returned more than one column.": [""],
       "Alert query returned a non-number value.": [""],
       "Alert found an error while executing a query.": [""],
       "Alert fired during grace period.": [""],
diff --git a/superset/translations/pt/LC_MESSAGES/message.po 
b/superset/translations/pt/LC_MESSAGES/message.po
index 7fba415fee..b944475c55 100644
--- a/superset/translations/pt/LC_MESSAGES/message.po
+++ b/superset/translations/pt/LC_MESSAGES/message.po
@@ -1788,12 +1788,12 @@ msgstr[1] ""
 
 #: superset/reports/commands/alert.py:74
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 
 #: superset/reports/commands/alert.py:83
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:44
@@ -1861,7 +1861,7 @@ msgid "Report Schedule reached a working timeout."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:138
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:143
@@ -1869,7 +1869,7 @@ msgid "Alert validator config error."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:147
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:151
diff --git a/superset/translations/pt_BR/LC_MESSAGES/messages.json 
b/superset/translations/pt_BR/LC_MESSAGES/messages.json
index 370a179c4d..253edc6ee4 100644
--- a/superset/translations/pt_BR/LC_MESSAGES/messages.json
+++ b/superset/translations/pt_BR/LC_MESSAGES/messages.json
@@ -705,10 +705,10 @@
         "%(num)d agendamento de relatório deletado",
         "%(num)d agendamentos de relatório deletados"
       ],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "A consulta de alerta retornou mais de uma linha. %s linhas retornadas"
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "A consulta de alerta retornou mais de uma coluna. %s colunas 
retornadas"
       ],
       "Dashboard does not exist": ["Painel não existe"],
@@ -753,13 +753,13 @@
       "Report Schedule reached a working timeout.": [
         "O agendamento de relatório atingiu o timeout de trabalho."
       ],
-      "Alert query returned more then one row.": [
+      "Alert query returned more than one row.": [
         "A consulta de alerta retornou mais de uma linha."
       ],
       "Alert validator config error.": [
         "Erro de configuração do validador de alerta."
       ],
-      "Alert query returned more then one column.": [
+      "Alert query returned more than one column.": [
         "A consulta de alerta retornou mais de uma coluna."
       ],
       "Alert query returned a non-number value.": [
diff --git a/superset/translations/pt_BR/LC_MESSAGES/messages.po 
b/superset/translations/pt_BR/LC_MESSAGES/messages.po
index 0092e89083..2441b2c768 100644
--- a/superset/translations/pt_BR/LC_MESSAGES/messages.po
+++ b/superset/translations/pt_BR/LC_MESSAGES/messages.po
@@ -1007,21 +1007,21 @@ msgid "Alert query returned a non-number value."
 msgstr "A consulta de alerta retornou um valor não numérico."
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "A consulta de alerta retornou mais de uma coluna."
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr "A consulta de alerta retornou mais de uma coluna. %s colunas 
retornadas"
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "A consulta de alerta retornou mais de uma linha."
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr "A consulta de alerta retornou mais de uma linha. %s linhas retornadas"
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/ru/LC_MESSAGES/messages.json 
b/superset/translations/ru/LC_MESSAGES/messages.json
index c100ba7f66..be3a0f1212 100644
--- a/superset/translations/ru/LC_MESSAGES/messages.json
+++ b/superset/translations/ru/LC_MESSAGES/messages.json
@@ -648,10 +648,10 @@
       ],
       "Saved query not found.": ["Сохранённый запрос не найден."],
       "Deleted %(num)d report schedule": ["Удалено %(num)d рассылок"],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "Запрос от оповещения вернул больше одной строки. %s строк возвращено"
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "Запрос от оповещения вернул больше одного столбца. %s столбцов 
возвращено"
       ],
       "Dashboard does not exist": ["Дашборд не существует"],
@@ -690,13 +690,13 @@
       "Report Schedule reached a working timeout.": [
         "Рассылка достигла тайм-аута в работе."
       ],
-      "Alert query returned more then one row.": [
+      "Alert query returned more than one row.": [
         "Запрос для оповещения вернул больше одной строки."
       ],
       "Alert validator config error.": [
         "Неверная конфигурация широты и долготы."
       ],
-      "Alert query returned more then one column.": [
+      "Alert query returned more than one column.": [
         "Запрос для оповещения вернул больше одного столбца."
       ],
       "Alert query returned a non-number value.": [
diff --git a/superset/translations/ru/LC_MESSAGES/messages.po 
b/superset/translations/ru/LC_MESSAGES/messages.po
index 9b79a3ea57..8cfde5eed5 100644
--- a/superset/translations/ru/LC_MESSAGES/messages.po
+++ b/superset/translations/ru/LC_MESSAGES/messages.po
@@ -984,21 +984,21 @@ msgid "Alert query returned a non-number value."
 msgstr "Запрос для оповещения вернул не число."
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "Запрос для оповещения вернул больше одного столбца."
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr "Запрос от оповещения вернул больше одного столбца. %s столбцов 
возвращено"
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "Запрос для оповещения вернул больше одной строки."
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr "Запрос от оповещения вернул больше одной строки. %s строк возвращено"
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/sk/LC_MESSAGES/messages.json 
b/superset/translations/sk/LC_MESSAGES/messages.json
index ba2b175e20..4418cabbf8 100644
--- a/superset/translations/sk/LC_MESSAGES/messages.json
+++ b/superset/translations/sk/LC_MESSAGES/messages.json
@@ -582,8 +582,8 @@
         "Deleted %(num)d report schedules"
       ],
       "Value must be greater than 0": [""],
-      "Alert query returned more then one row. %s rows returned": [""],
-      "Alert query returned more then one column. %s columns returned": [""],
+      "Alert query returned more than one row. %s rows returned": [""],
+      "Alert query returned more than one column. %s columns returned": [""],
       "Dashboard does not exist": [""],
       "Chart does not exist": [""],
       "Database is required for alerts": [""],
@@ -601,9 +601,9 @@
       "Report Schedule execution got an unexpected error.": [""],
       "Report Schedule is still working, refusing to re-compute.": [""],
       "Report Schedule reached a working timeout.": [""],
-      "Alert query returned more then one row.": [""],
+      "Alert query returned more than one row.": [""],
       "Alert validator config error.": [""],
-      "Alert query returned more then one column.": [""],
+      "Alert query returned more than one column.": [""],
       "Alert query returned a non-number value.": [""],
       "Alert found an error while executing a query.": [""],
       "A timeout occurred while executing the query.": [""],
diff --git a/superset/translations/sk/LC_MESSAGES/messages.po 
b/superset/translations/sk/LC_MESSAGES/messages.po
index cd8d69c0eb..6429587f83 100644
--- a/superset/translations/sk/LC_MESSAGES/messages.po
+++ b/superset/translations/sk/LC_MESSAGES/messages.po
@@ -919,21 +919,21 @@ msgid "Alert query returned a non-number value."
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr ""
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr ""
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr ""
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75
diff --git a/superset/translations/sl/LC_MESSAGES/messages.json 
b/superset/translations/sl/LC_MESSAGES/messages.json
index c5ac73ad0c..ab5e2067a7 100644
--- a/superset/translations/sl/LC_MESSAGES/messages.json
+++ b/superset/translations/sl/LC_MESSAGES/messages.json
@@ -963,10 +963,10 @@
         "Izbrisanih %(num)d urnikov poročanja"
       ],
       "Value must be greater than 0": ["Vrednost mora biti večja od 0"],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "Opozorilna poizvedba je vrnila več kot eno vrstico. Število vrnjenih 
vrstic: %s"
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "Opozorilna poizvedba je vrnila več kot en stolpec. Število vrnjenih 
stolpcev: %s"
       ],
       "Dashboard does not exist": ["Nadzorna plošča ne obstaja"],
@@ -1019,13 +1019,13 @@
       "Report Schedule reached a working timeout.": [
         "Urnik poročanja je dosegel mejo časa izvedbe."
       ],
-      "Alert query returned more then one row.": [
+      "Alert query returned more than one row.": [
         "Opozorilna poizvedba je vrnila več kot eno vrstico."
       ],
       "Alert validator config error.": [
         "Napaka nastavitev potrjevalnika opozoril."
       ],
-      "Alert query returned more then one column.": [
+      "Alert query returned more than one column.": [
         "Opozorilna poizvedba je vrnila več kot en stolpec."
       ],
       "Alert query returned a non-number value.": [
diff --git a/superset/translations/sl/LC_MESSAGES/messages.po 
b/superset/translations/sl/LC_MESSAGES/messages.po
index 5171d95052..2c9ad7bfcb 100644
--- a/superset/translations/sl/LC_MESSAGES/messages.po
+++ b/superset/translations/sl/LC_MESSAGES/messages.po
@@ -1002,23 +1002,23 @@ msgid "Alert query returned a non-number value."
 msgstr "Opozorilna poizvedba je vrnila neštevilsko vrednost."
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "Opozorilna poizvedba je vrnila več kot en stolpec."
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr ""
 "Opozorilna poizvedba je vrnila več kot en stolpec. Število vrnjenih "
 "stolpcev: %s"
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "Opozorilna poizvedba je vrnila več kot eno vrstico."
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr ""
 "Opozorilna poizvedba je vrnila več kot eno vrstico. Število vrnjenih "
 "vrstic: %s"
diff --git a/superset/translations/zh/LC_MESSAGES/messages.json 
b/superset/translations/zh/LC_MESSAGES/messages.json
index 8d803b45ab..b7fd50528e 100644
--- a/superset/translations/zh/LC_MESSAGES/messages.json
+++ b/superset/translations/zh/LC_MESSAGES/messages.json
@@ -559,10 +559,10 @@
       "Saved queries could not be deleted.": ["保存的查询无法被删除"],
       "Saved query not found.": ["保存的查询未找到"],
       "Deleted %(num)d report schedule": ["已经删除了 %(num)d 个报告时间表"],
-      "Alert query returned more then one row. %s rows returned": [
+      "Alert query returned more than one row. %s rows returned": [
         "警报查询返回了多行。%s 行被返回"
       ],
-      "Alert query returned more then one column. %s columns returned": [
+      "Alert query returned more than one column. %s columns returned": [
         "警报查询返回多个列。%s 列被返回"
       ],
       "Dashboard does not exist": ["看板不存在"],
@@ -589,9 +589,9 @@
         "报表计划仍在运行,拒绝重新计算。"
       ],
       "Report Schedule reached a working timeout.": ["报表计划已超时。"],
-      "Alert query returned more then one row.": ["警报查询返回了多行。"],
+      "Alert query returned more than one row.": ["警报查询返回了多行。"],
       "Alert validator config error.": ["错误的经纬度配置。"],
-      "Alert query returned more then one column.": ["警报查询返回多个列。"],
+      "Alert query returned more than one column.": ["警报查询返回多个列。"],
       "Alert query returned a non-number value.": ["警报查询返回非数字值。"],
       "Alert found an error while executing a query.": [
         "警报在执行查询时发现错误。"
diff --git a/superset/translations/zh/LC_MESSAGES/messages.po 
b/superset/translations/zh/LC_MESSAGES/messages.po
index 1d6e5e25b5..7b2570f792 100644
--- a/superset/translations/zh/LC_MESSAGES/messages.po
+++ b/superset/translations/zh/LC_MESSAGES/messages.po
@@ -969,21 +969,21 @@ msgid "Alert query returned a non-number value."
 msgstr "警报查询返回非数字值。"
 
 #: superset/reports/commands/exceptions.py:186
-msgid "Alert query returned more then one column."
+msgid "Alert query returned more than one column."
 msgstr "警报查询返回多个列。"
 
 #: superset/reports/commands/alert.py:105
 #, python-format
-msgid "Alert query returned more then one column. %s columns returned"
+msgid "Alert query returned more than one column. %s columns returned"
 msgstr "警报查询返回多个列。%s 列被返回"
 
 #: superset/reports/commands/exceptions.py:177
-msgid "Alert query returned more then one row."
+msgid "Alert query returned more than one row."
 msgstr "警报查询返回了多行。"
 
 #: superset/reports/commands/alert.py:96
 #, python-format
-msgid "Alert query returned more then one row. %s rows returned"
+msgid "Alert query returned more than one row. %s rows returned"
 msgstr "警报查询返回了多行。%s 行被返回"
 
 #: superset-frontend/src/views/CRUD/alert/components/AlertStatusIcon.tsx:75

Reply via email to
diff --git a/superset/reports/commands/alert.py 
b/superset/reports/commands/alert.py
index 7a18996df3..080fa3a3a7 100644
--- a/superset/reports/commands/alert.py
+++ b/superset/reports/commands/alert.py
@@ -88,20 +88,20 @@ class AlertCommand(BaseCommand):
 
     @staticmethod
     def _validate_result(rows: np.recarray) -> None:
         # check if query return more then one row
         if len(rows) > 1:
             raise AlertQueryMultipleRowsError(
                 message=_(
-                    "Alert query returned more then one row. %s rows returned"
+                    "Alert query returned more than one row. %s rows returned"
                     % len(rows),
                 )
             )
         # check if query returned more then one column
         if len(rows[0]) > 2:
             raise AlertQueryMultipleColumnsError(
                 # len is subtracted by 1 to discard pandas index column
                 _(
-                    "Alert query returned more then one column. %s columns 
returned"
+                    "Alert query returned more than one column. %s columns 
returned"
                     % (len(rows[0]) - 1)
                 )
@@ -88,20 +88,20 @@ class AlertCommand(BaseCommand):
     @staticmethod
     def _validate_result(rows: np.recarray) -> None:
-        # check if query return more then one row
+        # check if query return more than one row
         if len(rows) > 1:
             raise AlertQueryMultipleRowsError(
@@ -88,20 +88,20 @@ class AlertCommand(BaseCommand):
                 )
             )
-        # check if query returned more then one column
+        # check if query returned more than one column
         if len(rows[0]) > 2:
             raise AlertQueryMultipleColumnsError(
             )